import os, sys

os.chdir("..")
sys.path.append(".")

sys.argv.append("-jnml")

import Example4
